// ESA (C) 2000-2018 
//
// This file is part of ESA's XMM-Newton Scientific Analysis System (SAS).
//
//    SAS is free software: you can redistribute it and/or modify
//    it under the terms of the GNU General Public License as published by
//    the Free Software Foundation, either version 3 of the License, or
//    (at your option) any later version.
//
//    SAS is distributed in the hope that it will be useful,
//    but WITHOUT ANY WARRANTY; without even the implied warranty of
//    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
//    GNU General Public License for more details.
//
//    You should have received a copy of the GNU General Public License
//    along with SAS.  If not, see <http://www.gnu.org/licenses/>.
/* written by John Doug Reynolds, June 2002 */

#ifndef CALIB_H
#define CALIB_H

#include <scanningLib.h>
#include <vector>
#include <string>
#include "PhysicalConstants.h"

struct AngularDistBin {
   float phi0, phi1; // [arcmin] dispersion off-axis angles
   float value;
};
extern std::vector<AngularDistBin> customFigure;

const float hc = PhysicalConstants::eVtimesAo/1000.; //12.39854; // [keV Angstrom] energy times wavelength UPD 13/9/05

extern std::vector<double> vignetting;
//AI: Wavelength scale. Start
//void calibInit( const scanningLib::GridSpan &betaGrid, const int order);
void calVignetting( const scanningLib::GridSpan &betaChannelGrid,
		const float alpha);
void calibInit( const scanningLib::GridSpan &betaGrid, const scanningLib::GridSpan &betaChannelGrid,
		const scanningLib::GridSpan &betaORIChannelGrid, const int order);
//AI: Wavelength scale. End

void resetSourcePosition( float theta, float phi, int order );
void calibFree();

float calEnergy( float beta, int order, float alpha );
//AI: Wavelength scale. Start
float calLambdaEnergy( float lambda);
//AI: Wavelength scale. Start
float calAlpha0();

void ccd_qe( float qe[10], float energy );
float empiricalCrossLA( float energy, float dpsi, float xdsp0, float xdsp1 );
void prfBroad(std::vector<float>&, float eLow, float eHigh, float alpha, int order, std::string energyBinning);
void prfNarrow(	std::vector<float>&, float eLow, float eHigh, float alpha, int order,
			int fftdim,  bool withmirrorpsf=true, bool withangdist=false,
			std::string energyBinning=""  );

void corrEffArea(std::vector<float>&);
void interpolEffAreaCorr(std::vector<double> arfEnerMidPoints);
double getInterpolVal(double enerVal);

#endif /* CALIB_H */
